1.0.1
-----

* Add spidev and numpy dependencies.

1.0.0
-----

* Repackage to hatch/pyproject.toml
* Port to gpiod/gpiodevice

0.0.4
-----

* Add support for 320x240 2.0" LCD (Display HAT Mini)
* Add support for 240x135 1.14" LCD (@slabua)
* Rework numpy RGB888 to RGB565
* Support displaying numpy arrays (@zecktos)

0.0.3
-----

* Add support for RLCD
* Brought back `offset_left` and `offset_top` parameters

0.0.2
-----

* Fix for image retention
* Drop defunct parameters

0.0.1
-----

* Initial Release
